aboutsummaryrefslogtreecommitdiff
path: root/libcc1/libcc1.cc
diff options
context:
space:
mode:
Diffstat (limited to 'libcc1/libcc1.cc')
-rw-r--r--libcc1/libcc1.cc78
1 files changed, 41 insertions, 37 deletions
diff --git a/libcc1/libcc1.cc b/libcc1/libcc1.cc
index 572bc2a..0ef6c11 100644
--- a/libcc1/libcc1.cc
+++ b/libcc1/libcc1.cc
@@ -29,15 +29,15 @@ along with GCC; see the file COPYING3. If not see
#include <sys/stat.h>
#include <stdlib.h>
#include <sstream>
+#include "marshall-c.hh"
#include "rpc.hh"
#include "connection.hh"
#include "names.hh"
#include "callbacks.hh"
-#include "gcc-interface.h"
#include "libiberty.h"
#include "xregex.h"
#include "findcomp.hh"
-#include "compiler-name.h"
+#include "c-compiler-name.h"
#include "intl.h"
struct libcc1;
@@ -164,30 +164,35 @@ libcc1::~libcc1 ()
-// This is a wrapper function that is called by the RPC system and
-// that then forwards the call to the library user. Note that the
-// return value is not used; the type cannot be 'void' due to
-// limitations in our simple RPC.
-int
-call_binding_oracle (cc1_plugin::connection *conn,
- enum gcc_c_oracle_request request,
- const char *identifier)
-{
- libcc1 *self = ((libcc1_connection *) conn)->back_ptr;
+// Enclose these functions in an anonymous namespace because they
+// shouldn't be exported, but they can't be static because they're
+// used as template arguments.
+namespace {
+ // This is a wrapper function that is called by the RPC system and
+ // that then forwards the call to the library user. Note that the
+ // return value is not used; the type cannot be 'void' due to
+ // limitations in our simple RPC.
+ int
+ c_call_binding_oracle (cc1_plugin::connection *conn,
+ enum gcc_c_oracle_request request,
+ const char *identifier)
+ {
+ libcc1 *self = ((libcc1_connection *) conn)->back_ptr;
- self->binding_oracle (self->oracle_datum, self, request, identifier);
- return 1;
-}
+ self->binding_oracle (self->oracle_datum, self, request, identifier);
+ return 1;
+ }
-// This is a wrapper function that is called by the RPC system and
-// that then forwards the call to the library user.
-gcc_address
-call_symbol_address (cc1_plugin::connection *conn, const char *identifier)
-{
- libcc1 *self = ((libcc1_connection *) conn)->back_ptr;
+ // This is a wrapper function that is called by the RPC system and
+ // that then forwards the call to the library user.
+ gcc_address
+ c_call_symbol_address (cc1_plugin::connection *conn, const char *identifier)
+ {
+ libcc1 *self = ((libcc1_connection *) conn)->back_ptr;
- return self->address_oracle (self->oracle_datum, self, identifier);
-}
+ return self->address_oracle (self->oracle_datum, self, identifier);
+ }
+} /* anonymous namespace */
@@ -298,19 +303,19 @@ static const struct gcc_c_fe_vtable c_vtable =
set_callbacks,
#define GCC_METHOD0(R, N) \
- rpc<R, cc1_plugin::N>,
+ rpc<R, cc1_plugin::c::N>,
#define GCC_METHOD1(R, N, A) \
- rpc<R, cc1_plugin::N, A>,
+ rpc<R, cc1_plugin::c::N, A>,
#define GCC_METHOD2(R, N, A, B) \
- rpc<R, cc1_plugin::N, A, B>,
+ rpc<R, cc1_plugin::c::N, A, B>,
#define GCC_METHOD3(R, N, A, B, C) \
- rpc<R, cc1_plugin::N, A, B, C>,
+ rpc<R, cc1_plugin::c::N, A, B, C>,
#define GCC_METHOD4(R, N, A, B, C, D) \
- rpc<R, cc1_plugin::N, A, B, C, D>,
+ rpc<R, cc1_plugin::c::N, A, B, C, D>,
#define GCC_METHOD5(R, N, A, B, C, D, E) \
- rpc<R, cc1_plugin::N, A, B, C, D, E>,
+ rpc<R, cc1_plugin::c::N, A, B, C, D, E>,
#define GCC_METHOD7(R, N, A, B, C, D, E, F, G) \
- rpc<R, cc1_plugin::N, A, B, C, D, E, F, G>,
+ rpc<R, cc1_plugin::c::N, A, B, C, D, E, F, G>,
#include "gcc-c-fe.def"
@@ -377,13 +382,12 @@ libcc1::compiler::find (std::string &compiler ATTRIBUTE_UNUSED) const
char *
libcc1::compiler_triplet_regexp::find (std::string &compiler) const
{
- std::string rx = make_regexp (triplet_regexp_.c_str (), COMPILER_NAME);
+ std::string rx = make_regexp (triplet_regexp_.c_str (), C_COMPILER_NAME);
if (self_->verbose)
fprintf (stderr, _("searching for compiler matching regex %s\n"),
rx.c_str());
regex_t triplet;
- int code;
- code = regcomp (&triplet, rx.c_str (), REG_EXTENDED | REG_NOSUB);
+ int code = regcomp (&triplet, rx.c_str (), REG_EXTENDED | REG_NOSUB);
if (code != 0)
{
size_t len = regerror (code, &triplet, NULL, 0);
@@ -532,7 +536,7 @@ fork_exec (libcc1 *self, char **argv, int spair_fds[2], int stderr_fds[2])
cc1_plugin::status result = cc1_plugin::FAIL;
if (self->connection->send ('H')
- && ::cc1_plugin::marshall (self->connection, GCC_C_FE_VERSION_0))
+ && ::cc1_plugin::marshall (self->connection, GCC_C_FE_VERSION_1))
result = self->connection->wait_for_query ();
close (spair_fds[0]);
@@ -601,12 +605,12 @@ libcc1_compile (struct gcc_base_context *s,
= cc1_plugin::callback<int,
enum gcc_c_oracle_request,
const char *,
- call_binding_oracle>;
+ c_call_binding_oracle>;
self->connection->add_callback ("binding_oracle", fun);
fun = cc1_plugin::callback<gcc_address,
const char *,
- call_symbol_address>;
+ c_call_symbol_address>;
self->connection->add_callback ("address_oracle", fun);
char **argv = new (std::nothrow) char *[self->args.size () + 1];
@@ -663,7 +667,7 @@ gcc_c_fe_context (enum gcc_base_api_version base_version,
enum gcc_c_api_version c_version)
{
if ((base_version != GCC_FE_VERSION_0 && base_version != GCC_FE_VERSION_1)
- || c_version != GCC_C_FE_VERSION_0)
+ || (c_version != GCC_C_FE_VERSION_0 && c_version != GCC_C_FE_VERSION_1))
return NULL;
return new libcc1 (&vtable, &c_vtable);